# 2021-08-12 - Lido Relayer

> ⚠️ **DEPRECATED: do not use** ⚠️
>
> This relayer was superseded by an [updated version (also now deprecated)](../20211203-batch-relayer) with more features.

Deployment of the `LidoRelayer`, for using stETH with the Balancer Vault without having to wrap to wstETH separately.

## Useful Files

- [Ethereum mainnet addresses](./output/mainnet.json)
- [Goerli testnet addresses](./output/goerli.json)
- [`LidoRelayer` artifact](./artifact/LidoRelayer.json)
